==> lsof_4.37.orig.tar.gz: lsof-4.37.orig/dialects/ptx/dproto.h <==
/*
 * dproto.h - PTX function prototypes for lsof
 *
 * The _PROTOTYPE macro is defined in the common proto.h.
 */


/*
 * Copyright 1995 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */


/*
 * $Id: dproto.h,v 1.3 98/03/06 08:27:41 abe Exp $
 */


_PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev));
_PROTOTYPE(extern void findclones,(void));
_PROTOTYPE(extern int is_file_named,(char *p, enum vtype ty));
_PROTOTYPE(extern void process_socket,(char *pn, int fam, int ipid, KA_T pa));
_PROTOTYPE(extern int readinode,(KA_T ia, struct inode *i));
_PROTOTYPE(extern struct l_vfs *readvfs,(struct vnode *va));

#if	defined(HAS_NFS)
_PROTOTYPE(extern int readrnode,(KA_T ra, struct rnode *r));
#endif	/* defined(HAS_NFS) */

#if	PTXV>=421
_PROTOTYPE(extern void process_unix_socket,(struct socket *s, struct unpcb *u));
#endif	/* PTXV>=421 */

#if	defined(HASVXFS)
_PROTOTYPE(extern int read_vxinode,(struct vnode *v, struct l_vfs *vfs, dev_t *dev));
# if	defined(HASNCACHE) && defined(HASVXFSDNLC)
_PROTOTYPE(extern int read_vxvnode,(KA_T va, struct vnode *v));
# endif	/* defined(HASNCACHE) && defined(HASVXFSDNLC) */
#endif	/* defined(HASVXFS) */

==> lsof_4.48.orig.tar.gz: lsof_4.48/dialects/ptx/dproto.h <==
/*
 * dproto.h - PTX function prototypes for lsof
 *
 * The _PROTOTYPE macro is defined in the common proto.h.
 */


/*
 * Copyright 1995 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */


/*
 * $Id: dproto.h,v 1.4 99/01/25 07:12:22 abe Exp $
 */


_PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev));
_PROTOTYPE(extern void findclones,(void));
_PROTOTYPE(extern int is_file_named,(char *p, int cd));
_PROTOTYPE(extern void process_socket,(char *pn, int fam, int ipid, KA_T pa, void *lsp));
_PROTOTYPE(extern int readinode,(KA_T ia, struct inode *i));
_PROTOTYPE(extern struct l_vfs *readvfs,(struct vnode *va));

#if	defined(HAS_NFS)
_PROTOTYPE(extern int readrnode,(KA_T ra, struct rnode *r));
#endif	/* defined(HAS_NFS) */

#if	PTXV>=421
_PROTOTYPE(extern void process_unix_socket,(struct socket *s, struct unpcb *u));
#endif	/* PTXV>=421 */

#if	defined(HASVXFS)
_PROTOTYPE(extern int read_vxinode,(struct vnode *v, struct l_vfs *vfs, dev_t *dev));
# if	defined(HASNCACHE) && defined(HASVXFSDNLC)
_PROTOTYPE(extern int read_vxvnode,(KA_T va, struct vnode *v));
# endif	/* defined(HASNCACHE) && defined(HASVXFSDNLC) */
#endif	/* defined(HASVXFS) */
